module.exports = defineTest({
	description: 'handle recursive reassignments of return values'
});
